<a name="module_messageformat-runtime/messages"></a>

## messageformat-runtime/messages

Accessor class for compiled message functions generated by [messageformat](https://www.npmjs.com/package/messageformat)

```js
import Messages from 'messageformat-runtime/messages';
```

- [messageformat-runtime/messages](#module_messageformat-runtime/messages)
  - [module.exports](#exp_module_messageformat-runtime/messages--module.exports) ⏏
    - [new module.exports(msgData, [defaultLocale])](#new_module_messageformat-runtime/messages--module.exports_new)
    - [.availableLocales](#module_messageformat-runtime/messages--module.exports+availableLocales) : <code>Array.&lt;string&gt;</code>
    - [.locale](#module_messageformat-runtime/messages--module.exports+locale) : <code>string</code> \| <code>null</code>
    - [.defaultLocale](#module_messageformat-runtime/messages--module.exports+defaultLocale) : <code>string</code> \| <code>null</code>
    - [.addMessages(data, [lc], [keypath])](#module_messageformat-runtime/messages--module.exports+addMessages) ⇒ <code>Messages</code>
    - [.resolveLocale(lc)](#module_messageformat-runtime/messages--module.exports+resolveLocale) ⇒ <code>string</code> \| <code>null</code>
    - [.getFallback([lc])](#module_messageformat-runtime/messages--module.exports+getFallback) ⇒ <code>Array.&lt;string&gt;</code>
    - [.setFallback(lc, fallback)](#module_messageformat-runtime/messages--module.exports+setFallback) ⇒ <code>Messages</code>
    - [.hasMessage(key, [lc], [fallback])](#module_messageformat-runtime/messages--module.exports+hasMessage) ⇒ <code>boolean</code>
    - [.hasObject(key, [lc], [fallback])](#module_messageformat-runtime/messages--module.exports+hasObject) ⇒ <code>boolean</code>
    - [.get(key, [props], [lc])](#module_messageformat-runtime/messages--module.exports+get) ⇒ <code>string</code> \| <code>Object.&lt;string, (function()\|object)&gt;</code>

<a name="exp_module_messageformat-runtime/messages--module.exports"></a>

### module.exports ⏏

**Kind**: Exported class  
<a name="new_module_messageformat-runtime/messages--module.exports_new"></a>

#### new module.exports(msgData, [defaultLocale])

| Param           | Type                | Description                                                                |
| --------------- | ------------------- | -------------------------------------------------------------------------- |
| msgData         | <code>object</code> | A map of locale codes to their function objects                            |
| [defaultLocale] | <code>string</code> | If not defined, default and initial locale is the first entry of `locales` |

**Example**

```js
// build.js
import fs from 'fs';
import MessageFormat from 'messageformat';

const mf = new MessageFormat(['en', 'fi']);
const msgSet = {
  en: {
    a: 'A {TYPE} example.',
    b: 'This has {COUNT, plural, one{one user} other{# users}}.',
    c: {
      d: 'We have {P, number, percent} code coverage.'
    }
  },
  fi: {
    b: 'Tällä on {COUNT, plural, one{yksi käyttäjä} other{# käyttäjää}}.',
    e: 'Minä puhun vain suomea.'
  }
};
fs.writeFileSync('messages.js', String(mf.compile(msgSet)));
```

```js
// runtime.js
import Messages from 'messageformat-runtime/messages';
import msgData from './messages';

const messages = new Messages(msgData, 'en');

messages.hasMessage('a'); // true
messages.hasObject('c'); // true
messages.get('b', { COUNT: 3 }); // 'This has 3 users.'
messages.get(['c', 'd'], { P: 0.314 }); // 'We have 31% code coverage.'

messages.get('e'); // 'e'
messages.setFallback('en', ['foo', 'fi']);
messages.get('e'); // 'Minä puhun vain suomea.'

messages.locale = 'fi';
messages.hasMessage('a'); // false
messages.hasMessage('a', 'en'); // true
messages.hasMessage('a', null, true); // true
messages.hasObject('c'); // false
messages.get('b', { COUNT: 3 }); // 'Tällä on 3 käyttäjää.'
messages.get('c').d({ P: 0.628 }); // 'We have 63% code coverage.'
```

<a name="module_messageformat-runtime/messages--module.exports+availableLocales"></a>

#### module.exports.availableLocales : <code>Array.&lt;string&gt;</code>

List of available locales

**Kind**: instance property of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)  
**Read only**: true  
<a name="module_messageformat-runtime/messages--module.exports+locale"></a>

#### module.exports.locale : <code>string</code> \| <code>null</code>

Current locale

One of Messages#availableLocales or `null`. Partial matches of language tags
are supported, so e.g. with an `en` locale defined, it will be selected by
`messages.locale = 'en-US'` and vice versa.

**Kind**: instance property of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)  
<a name="module_messageformat-runtime/messages--module.exports+defaultLocale"></a>

#### module.exports.defaultLocale : <code>string</code> \| <code>null</code>

Default fallback locale

One of Messages#availableLocales or `null`. Partial matches of language tags
are supported, so e.g. with an `en` locale defined, it will be selected by
`messages.defaultLocale = 'en-US'` and vice versa.

**Kind**: instance property of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)  
<a name="module_messageformat-runtime/messages--module.exports+addMessages"></a>

#### module.exports.addMessages(data, [lc], [keypath]) ⇒ <code>Messages</code>

Add new messages to the accessor; useful if loading data dynamically

The locale code `lc` should be an exact match for the locale being updated,
or empty to default to the current locale. Use [#resolveLocale](#resolveLocale) for
resolving partial locale strings.

If `keypath` is empty, adds or sets the complete message object for the
corresponding locale. If any keys in `keypath` do not exist, a new object
will be created at that key.

**Kind**: instance method of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)  
**Returns**: <code>Messages</code> - The Messages instance, to allow for chaining

| Param     | Type                                         | Description                                                         |
| --------- | -------------------------------------------- | ------------------------------------------------------------------- |
| data      | <code>function</code> \| <code>object</code> | Hierarchical map of keys to functions, or a single message function |
| [lc]      | <code>string</code>                          | If empty or undefined, defaults to `this.locale`                    |
| [keypath] | <code>Array.&lt;string&gt;</code>            | The keypath being added                                             |

<a name="module_messageformat-runtime/messages--module.exports+resolveLocale"></a>

#### module.exports.resolveLocale(lc) ⇒ <code>string</code> \| <code>null</code>

Resolve `lc` to the key of an available locale or `null`, allowing for
partial matches. For example, with an `en` locale defined, it will be
selected by `messages.defaultLocale = 'en-US'` and vice versa.

**Kind**: instance method of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)

| Param | Type                | Description |
| ----- | ------------------- | ----------- |
| lc    | <code>string</code> | Locale code |

<a name="module_messageformat-runtime/messages--module.exports+getFallback"></a>

#### module.exports.getFallback([lc]) ⇒ <code>Array.&lt;string&gt;</code>

Get the list of fallback locales

**Kind**: instance method of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)

| Param | Type                | Description                                      |
| ----- | ------------------- | ------------------------------------------------ |
| [lc]  | <code>string</code> | If empty or undefined, defaults to `this.locale` |

<a name="module_messageformat-runtime/messages--module.exports+setFallback"></a>

#### module.exports.setFallback(lc, fallback) ⇒ <code>Messages</code>

Set the fallback locale or locales for `lc`

To disable fallback for the locale, use `setFallback(lc, [])`.
To use the default fallback, use `setFallback(lc, null)`.

**Kind**: instance method of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)  
**Returns**: <code>Messages</code> - The Messages instance, to allow for chaining

| Param    | Type                                                   |
| -------- | ------------------------------------------------------ |
| lc       | <code>string</code>                                    |
| fallback | <code>Array.&lt;string&gt;</code> \| <code>null</code> |

<a name="module_messageformat-runtime/messages--module.exports+hasMessage"></a>

#### module.exports.hasMessage(key, [lc], [fallback]) ⇒ <code>boolean</code>

Check if `key` is a message function for the locale

`key` may be a `string` for functions at the root level, or `string[]` for
accessing hierarchical objects. If an exact match is not found and `fallback`
is true, the fallback locales are checked for the first match.

**Kind**: instance method of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)

| Param      | Type                                                     | Default            | Description                                      |
| ---------- | -------------------------------------------------------- | ------------------ | ------------------------------------------------ |
| key        | <code>string</code> \| <code>Array.&lt;string&gt;</code> |                    | The key or keypath being sought                  |
| [lc]       | <code>string</code>                                      |                    | If empty or undefined, defaults to `this.locale` |
| [fallback] | <code>boolean</code>                                     | <code>false</code> | If true, also checks fallback locales            |

<a name="module_messageformat-runtime/messages--module.exports+hasObject"></a>

#### module.exports.hasObject(key, [lc], [fallback]) ⇒ <code>boolean</code>

Check if `key` is a message object for the locale

`key` may be a `string` for functions at the root level, or `string[]` for
accessing hierarchical objects. If an exact match is not found and `fallback`
is true, the fallback locales are checked for the first match.

**Kind**: instance method of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)

| Param      | Type                                                     | Default            | Description                                      |
| ---------- | -------------------------------------------------------- | ------------------ | ------------------------------------------------ |
| key        | <code>string</code> \| <code>Array.&lt;string&gt;</code> |                    | The key or keypath being sought                  |
| [lc]       | <code>string</code>                                      |                    | If empty or undefined, defaults to `this.locale` |
| [fallback] | <code>boolean</code>                                     | <code>false</code> | If true, also checks fallback locales            |

<a name="module_messageformat-runtime/messages--module.exports+get"></a>

#### module.exports.get(key, [props], [lc]) ⇒ <code>string</code> \| <code>Object.&lt;string, (function()\|object)&gt;</code>

Get the message or object corresponding to `key`

`key` may be a `string` for functions at the root level, or `string[]` for
accessing hierarchical objects. If an exact match is not found, the fallback
locales are checked for the first match.

If `key` maps to a message function, it will be called with `props`. If it
maps to an object, the object is returned directly.

**Kind**: instance method of [<code>module.exports</code>](#exp_module_messageformat-runtime/messages--module.exports)

| Param   | Type                                                     | Description                                      |
| ------- | -------------------------------------------------------- | ------------------------------------------------ |
| key     | <code>string</code> \| <code>Array.&lt;string&gt;</code> | The key or keypath being sought                  |
| [props] | <code>object</code>                                      | Optional properties passed to the function       |
| [lc]    | <code>string</code>                                      | If empty or undefined, defaults to `this.locale` |
